@@ -3,7 +3,7 @@
 // Purpose:     
 // Author:      Alex Thuering
 // Created:     2005/04/28
-// RCS-ID:      $Id: Document.h,v 1.3 2007/05/24 08:59:13 etisserant Exp $
+// RCS-ID:      $Id: Document.h,v 1.4 2010/08/17 08:00:29 ntalex Exp $
 // Copyright:   (c) 2005 Alex Thuering
 // Licence:     wxWindows licence
 //////////////////////////////////////////////////////////////////////////////
@@ -11,6 +11,10 @@
 #ifndef wxSVG_DOCUMENT_H
 #define wxSVG_DOCUMENT_H
 
+#ifdef GetCurrentTime
+#undef GetCurrentTime
+#endif
+
 #include "wxSVGXML/svgxml.h"
 
 #endif //wxSVG_DOCUMENT_H
