@@ -3,36 +3,23 @@
 // Purpose:     FFMPEG Media Decoder
 // Author:      Alex Thuering
 // Created:     21.07.2007
-// RCS-ID:      $Id: mediadec_ffmpeg.cpp,v 1.16 2012/01/09 15:58:44 ntalex Exp $
+// RCS-ID:      $Id: mediadec_ffmpeg.cpp,v 1.20 2012/04/11 20:50:33 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
+#define __STDC_CONSTANT_MACROS
+#define __STDC_LIMIT_MACROS
+
 #include <wxSVG/mediadec_ffmpeg.h>
 #include <wx/wx.h>
 #include <errno.h>
 
-#define INT64_C(val) val##LL
-#define UINT64_C(val) val##ULL
-#ifndef int64_t_C
-#define int64_t_C(c)     (c ## LL)
-#define uint64_t_C(c)    (c ## ULL)
-#endif
-#ifndef INT64_MAX
-#define INT64_MAX int64_t_C(0x7fffffffffffffff)
-#endif
 extern "C" {
-#define __STDC_CONSTANT_MACROS
-#define __STDC_LIMIT_MACROS
-#ifdef HAVE_FFMPEG_AVUTIL_H
-#include <avformat.h>
-#include <swscale.h>
-#include <avutil.h>
-#else
 #include <libavformat/avformat.h>
 #include <libswscale/swscale.h>
 #include <libavutil/avutil.h>
-#endif
+#include <libavutil/mathematics.h>
 }
 
 wxFfmpegMediaDecoder::wxFfmpegMediaDecoder(): m_formatCtx(NULL), m_codecCtx(NULL), m_frame(NULL) {
@@ -162,10 +149,9 @@ int wxFfmpegMediaDecoder::GetBitrate(unsigned int streamIndex) {
 	return m_formatCtx ? m_formatCtx->streams[streamIndex]->codec->bit_rate : -1;
 }
 
-double wxFfmpegMediaDecoder::GetDuration()
-{
-    return m_formatCtx != NULL && m_formatCtx->duration != (int)AV_NOPTS_VALUE ?
-      m_formatCtx->duration / AV_TIME_BASE : -1;
+double wxFfmpegMediaDecoder::GetDuration() {
+	return m_formatCtx != NULL && m_formatCtx->duration != (int)AV_NOPTS_VALUE ?
+			((double)m_formatCtx->duration) / AV_TIME_BASE : -1;
 }
 
 bool wxFfmpegMediaDecoder::OpenVideoDecoder() {
